pub const unsafe fn encode() -> EncodedX86_64InstructionExpand description
Return to calling procedure.
Safety
This function is safe to call. It is marked as unsafe for consistency with other encoders.
pub const unsafe fn encode() -> EncodedX86_64InstructionReturn to calling procedure.
This function is safe to call. It is marked as unsafe for consistency with other encoders.